@@ -89,9 +89,11 @@ class MemcachedLock(locking.Lock):
                 return False
             return owner == self.coord._member_id
 
-    def acquire(self, blocking=True, shared=False):
+    def acquire(self, blocking=True, shared=False, timeout=None):
         if shared:
             raise tooz.NotImplemented
+        if timeout is not None:
+            raise tooz.Timeout
 
         @_retry.retry(stop_max_delay=blocking)
         @_translate_failures
