@@ -71,7 +71,7 @@ def _format_exception(e):
             attr_value = getattr(e.diag, attr_name)
             if attr_value is None:
                 continue
-            diagnostic_lines.append("  %s = %s" (attr_name, attr_value))
+            diagnostic_lines.append("  %s = %s" % (attr_name, attr_value))
         if diagnostic_lines:
             lines.append('Diagnostics:')
             lines.extend(diagnostic_lines)
@@ -102,10 +102,12 @@ class PostgresLock(locking.Lock):
         h.update(name)
         self.key = h.digest()[0:2]
 
-    def acquire(self, blocking=True, shared=False):
+    def acquire(self, blocking=True, shared=False, timeout=None):
 
         if shared:
             raise tooz.NotImplemented
+        if timeout is not None:
+            raise tooz.NotImplemented
 
         @_retry.retry(stop_max_delay=blocking)
         def _lock():
